function f = mykpp1d( phi, Id, X )
%Structural  model mykpp1d - Ecrite en septembre 2012
%KPP 1d interpolation - Full param
%
%Model information:
% # outputs = 1
% # regression variables = 1
% # parameters = 3
%
%f = mykpp1d(phi,Id,X) returns a vector of length n
%         phi (N x 3) individual parameters.
%
%         X  structure with regression data
%              obs (n x 1) =  regression variables: x
%
%         Id  structure with individual index informations
%              obs (n x 1) =  individual index for each observation
%              Nbs (N x 2) =  number of doses (0 if none) and observations per subject
%
% where
%     N = number of subjects
%     n = number of observations
%

% if no arguments are given then we return the informations of the model
try
    phi;
catch
    f=getdata;
    return
end

%########    To Check with latest version   ###################

% ###  Parameters
r  = phi(:,1);
d  = phi(:,2);
x0 = phi(:,3);

% ### Size of datas
N = size(phi,1);

param = [r,d,x0];

Nbs_obs1 = Id.Nbs(:,2);

i_obs12 = 0;

outp1 = [];

% ### Load the db
% ### The matrix is called bdd
% ### The matrix is a global variable
global bdd;

% ### Time step corresponding to the DB
global tbdd;

for i=1:N
    i_obs11 = i_obs12 + 1;
    i_obs12 = i_obs12 + Nbs_obs1(i);
    % ### observation times of subject i for the first (size) observation    
    t_obsi1 = X.obs(i_obs11:i_obs12);
    % ### parameters of subject i
    parami= [param(i,:)]; 
    
    S = kpp1d_child(parami(1,1),parami(1,2),parami(1,3),t_obsi1,tbdd,bdd);
    outp1 = [outp1;S];
end


%##################################################

f = outp1;

end

%####################################
%####################################
% function model_info = getdata
function model_info = getdata
%returns the information about this model

model_info=struct;

model_info.nb_param=3;% number of parameters "phi"
model_info.phi_names={...
    'r',...
    'd',...
    'x0'};% names of the parameters
model_info.phi_tex={...
    'R',...
    'D',...
    'x_0'};% tex names of the parameters for the plots
model_info.logstruct={...
    'L',...
    'L',...
    'L'};% default distribution of the parameters "phi"

model_info.nb_varex=1;% number of regression variables
model_info.x_names={'x'};% name of the regression variable
model_info.x_tex={''};% tex name of the regression variable for the plots

model_info.nb_outputs=1;% number of outputs
model_info.y_names={'y'};% name of the output
model_info.y_tex={''};% tex name of the output for the plots

model_info.nb_ode=0;% number of differential equations
model_info.ode=0;% name of the output

model_info.iop_ode=0;% type of solver

model_info.dose=0;% 1 if the model needs dose information

model_info.cat_model='other';% type of model

model_info.desc='KPP 1d interpolation - Full param';%description of the model

end
